@@ -76,6 +76,7 @@ To report issues go to https://github.com/holoviz/holoviews.
 import builtins
 import os
 import sys
+from typing import TYPE_CHECKING
 
 import param
 
@@ -132,6 +133,11 @@ if '_pyodide' in sys.modules:
         extension = pyodide_extension
     del pyodide_extension, in_jupyterlite
 
+
+if TYPE_CHECKING:
+    # Adding this here to have better docstring in LSP
+    from .util import extension
+
 # A single holoviews.rc file may be executed if found.
 for rcfile in [os.environ.get("HOLOVIEWSRC", ''),
                os.path.abspath(os.path.join(os.path.split(__file__)[0],
@@ -186,7 +192,7 @@ def __getattr__(name):
     raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
 
 __all__ = [k for k in locals() if not k.startswith('_')]
-__all__ += ['annotate', '__version__']
+__all__ += ['__version__', 'annotate']
 
 def __dir__():
     return __all__
