@@ -1,39 +1,37 @@
-import types
 import copy
-
+import types
 from contextlib import contextmanager
 from functools import wraps
 
 import numpy as np
 import param
-import pandas as pd # noqa
-
 from param.parameterized import ParameterizedMetaclass
 
+from .. import util as core_util
 from ..accessors import Redim
 from ..dimension import (
-    Dimension, Dimensioned, LabelledData, dimension_name, process_dimensions
+    Dimension,
+    Dimensioned,
+    LabelledData,
+    dimension_name,
+    process_dimensions,
 )
 from ..element import Element
-from ..ndmapping import OrderedDict, MultiDimensionalMapping
-from ..spaces import HoloMap, DynamicMap
-
-from .array import ArrayInterface             # noqa (API import)
-from .cudf import cuDFInterface               # noqa (API import)
-from .dask import DaskInterface               # noqa (API import)
-from .dictionary import DictInterface         # noqa (API import)
-from .grid import GridInterface               # noqa (API import)
-from .ibis import IbisInterface               # noqa (API import)
-from .interface import Interface, iloc, ndloc # noqa (API import)
-from .multipath import MultiInterface         # noqa (API import)
-from .image import ImageInterface             # noqa (API import)
-from .pandas import PandasInterface           # noqa (API import)
-from .spatialpandas import SpatialPandasInterface     # noqa (API import)
-from .spatialpandas_dask import DaskSpatialPandasInterface # noqa (API import)
-from .xarray import XArrayInterface           # noqa (API import)
-
-# Ensures correct holoviews.core.util is sourced
-from .. import util
+from ..ndmapping import MultiDimensionalMapping
+from ..spaces import DynamicMap, HoloMap
+from .array import ArrayInterface
+from .cudf import cuDFInterface  # noqa (API import)
+from .dask import DaskInterface  # noqa (API import)
+from .dictionary import DictInterface  # noqa (API import)
+from .grid import GridInterface  # noqa (API import)
+from .ibis import IbisInterface  # noqa (API import)
+from .image import ImageInterface  # noqa (API import)
+from .interface import Interface, iloc, ndloc
+from .multipath import MultiInterface  # noqa (API import)
+from .pandas import PandasAPI, PandasInterface  # noqa (API import)
+from .spatialpandas import SpatialPandasInterface  # noqa (API import)
+from .spatialpandas_dask import DaskSpatialPandasInterface  # noqa (API import)
+from .xarray import XArrayInterface  # noqa (API import)
 
 default_datatype = 'dataframe'
 
@@ -109,8 +107,7 @@ class DataConversion:
             min_d, max_d = element_params[dim_type].bounds
             if ((min_d is not None and len(dims) < min_d) or
                 (max_d is not None and len(dims) > max_d)):
-                raise ValueError("%s %s must be between length %s and %s." %
-                                 (type_name, dim_type, min_d, max_d))
+                raise ValueError(f"{type_name} {dim_type} must be between length {min_d} and {max_d}.")
 
         if groupby is None:
             groupby = [d for d in self._element.kdims if d not in kdims+vdims]
@@ -123,16 +120,15 @@ class DataConversion:
                 selected = self._element.reindex(groupby+kdims, vdims)
             else:
                 selected = self._element
+        elif issubclass(self._element.interface, PandasAPI):
+            ds_dims = self._element.dimensions()
+            ds_kdims = [self._element.get_dimension(d) if d in ds_dims else d
+                        for d in groupby+kdims]
+            ds_vdims = [self._element.get_dimension(d) if d in ds_dims else d
+                        for d in vdims]
+            selected = self._element.clone(kdims=ds_kdims, vdims=ds_vdims)
         else:
-            if issubclass(self._element.interface, PandasInterface):
-                ds_dims = self._element.dimensions()
-                ds_kdims = [self._element.get_dimension(d) if d in ds_dims else d
-                            for d in groupby+kdims]
-                ds_vdims = [self._element.get_dimension(d) if d in ds_dims else d
-                            for d in vdims]
-                selected = self._element.clone(kdims=ds_kdims, vdims=ds_vdims)
-            else:
-                selected = self._element.reindex(groupby+kdims, vdims)
+            selected = self._element.reindex(groupby+kdims, vdims)
         params = {'kdims': [selected.get_dimension(kd, strict=True) for kd in kdims],
                   'vdims': [selected.get_dimension(vd, strict=True) for vd in vdims],
                   'label': selected.label}
@@ -210,7 +206,7 @@ class PipelineMeta(ParameterizedMetaclass):
                 if not in_method:
                     if isinstance(result, Dataset):
                         result._pipeline = inst_pipeline.instance(
-                            operations=inst_pipeline.operations + [op],
+                            operations=[*inst_pipeline.operations, op],
                             output_type=type(result),
                         )
 
@@ -223,9 +219,7 @@ class PipelineMeta(ParameterizedMetaclass):
                                     args=[key]
                                 )
                                 element._pipeline = inst_pipeline.instance(
-                                    operations=inst_pipeline.operations + [
-                                        op, getitem_op
-                                    ],
+                                    operations=[*inst_pipeline.operations, op, getitem_op],
                                     output_type=type(result),
                                 )
             finally:
@@ -248,7 +242,7 @@ class Dataset(Element, metaclass=PipelineMeta):
     function.
     """
 
-    datatype = param.List(datatypes, doc="""
+    datatype = param.List(default=datatypes, doc="""
         A priority list of the data types to be used for storage
         on the .data attribute. If the input supplied to the element
         constructor cannot be put into the requested format, the next
@@ -270,6 +264,8 @@ class Dataset(Element, metaclass=PipelineMeta):
     _vdim_reductions = {}
     _kdim_reductions = {}
 
+    interface: Interface
+
     def __new__(cls, data=None, kdims=None, vdims=None, **kwargs):
         """
         Allows casting a DynamicMap to an Element class like hv.Curve, by applying the
@@ -293,7 +289,8 @@ class Dataset(Element, metaclass=PipelineMeta):
 
     def __init__(self, data, kdims=None, vdims=None, **kwargs):
         from ...operation.element import (
-            chain as chain_op, factory
+            chain as chain_op,
+            factory,
         )
         self._in_method = False
         input_data = data
@@ -313,7 +310,7 @@ class Dataset(Element, metaclass=PipelineMeta):
                     data.get_dimension(vd) if isinstance(vd, str) else vd
                     for vd in kwargs['vdims']
                 ]
-            pvals = util.get_param_values(data)
+            pvals = core_util.get_param_values(data)
             kwargs.update([(l, pvals[l]) for l in ['group', 'label']
                            if l in pvals and l not in kwargs])
         if isinstance(data, Dataset):
@@ -346,7 +343,7 @@ class Dataset(Element, metaclass=PipelineMeta):
             kwargs=dict(kwargs, kdims=self.kdims, vdims=self.vdims),
         )
         self._pipeline = input_pipeline.instance(
-            operations=input_pipeline.operations + [init_op],
+            operations=[*input_pipeline.operations, init_op],
             output_type=type(self),
         )
         self._transforms = input_transforms or []
@@ -388,7 +385,7 @@ class Dataset(Element, metaclass=PipelineMeta):
         if self._dataset is None:
             if type(self) is Dataset:
                 return self
-            datatype = list(util.unique_iterator(self.datatype+Dataset.datatype))
+            datatype = list(core_util.unique_iterator(self.datatype+Dataset.datatype))
             dataset = Dataset(self, dataset=None, pipeline=None, transforms=None,
                               _validate_vdims=False, datatype=datatype)
             if hasattr(self, '_binned'):
@@ -435,7 +432,7 @@ class Dataset(Element, metaclass=PipelineMeta):
         self._cached = persisted
         return self
 
-    def closest(self, coords=[], **kwargs):
+    def closest(self, coords=None, **kwargs):
         """Snaps coordinate(s) to closest coordinate in Dataset
 
         Args:
@@ -448,6 +445,8 @@ class Dataset(Element, metaclass=PipelineMeta):
         Raises:
             NotImplementedError: Raised if snapping is not supported
         """
+        if coords is None:
+            coords = []
         if self.ndims > 1:
             raise NotImplementedError("Closest method currently only "
                                       "implemented for 1D Elements")
@@ -456,7 +455,7 @@ class Dataset(Element, metaclass=PipelineMeta):
             if len(kwargs) > 1:
                 raise NotImplementedError("Closest method currently only "
                                           "supports 1D indexes")
-            samples = list(kwargs.values())[0]
+            samples = next(iter(kwargs.values()))
             coords = samples if isinstance(samples, list) else [samples]
 
         xs = self.dimension_values(0)
@@ -502,15 +501,15 @@ class Dataset(Element, metaclass=PipelineMeta):
 
         if dim is None or (not data_range and not dimension_range):
             return (None, None)
-        elif all(util.isfinite(v) for v in dim.range) and dimension_range:
+        elif all(core_util.isfinite(v) for v in dim.range) and dimension_range:
             return dim.range
         elif dim in self.dimensions() and data_range and bool(self):
             lower, upper = self.interface.range(self, dim)
         else:
-            lower, upper = (np.NaN, np.NaN)
+            lower, upper = (np.nan, np.nan)
         if not dimension_range:
             return lower, upper
-        return util.dimension_range(lower, upper, dim.range, dim.soft_range)
+        return core_util.dimension_range(lower, upper, dim.range, dim.soft_range)
 
 
     def add_dimension(self, dimension, dim_pos, dim_val, vdim=False, **kwargs):
@@ -607,8 +606,8 @@ argument to specify a selection specification""")
 
         if selection_specs is not None and not isinstance(selection_specs, (list, tuple)):
             selection_specs = [selection_specs]
-        selection = {dim_name: sel for dim_name, sel in selection.items()
-                     if dim_name in self.dimensions()+['selection_mask']}
+        sel_dims = (*self.dimensions(), 'selection_mask')
+        selection = {dim: sel for dim, sel in selection.items() if dim in sel_dims}
         if (selection_specs and not any(self.matches(sp) for sp in selection_specs)
             or (not selection and not selection_expr)):
             return self
@@ -653,12 +652,12 @@ argument to specify a selection specification""")
             # If no key dimensions are defined and interface is gridded
             # drop all scalar key dimensions
             key_dims = [d for d in self.kdims if (not vdims or d not in vdims)
-                        and not d in scalars]
+                        and d not in scalars]
         elif not isinstance(kdims, list):
             key_dims = [self.get_dimension(kdims, strict=True)]
         else:
             key_dims = [self.get_dimension(k, strict=True) for k in kdims]
-        dropped = [d for d in self.kdims if not d in key_dims and not d in scalars]
+        dropped = [d for d in self.kdims if d not in key_dims and d not in scalars]
 
         new_type = None
         if vdims is None:
@@ -693,7 +692,7 @@ argument to specify a selection specification""")
            (4) A boolean array index matching the length of the Dataset
                object.
         """
-        slices = util.process_ellipses(self, slices, vdim_selection=True)
+        slices = core_util.process_ellipses(self, slices, vdim_selection=True)
         if getattr(getattr(slices, 'dtype', None), 'kind', None) == 'b':
             if not len(slices) == len(self):
                 raise IndexError("Boolean index must match length of sliced object")
@@ -721,7 +720,7 @@ argument to specify a selection specification""")
         return data
 
 
-    def sample(self, samples=[], bounds=None, closest=True, **kwargs):
+    def sample(self, samples=None, bounds=None, closest=True, **kwargs):
         """Samples values at supplied coordinates.
 
         Allows sampling of element with a list of coordinates matching
@@ -753,6 +752,8 @@ argument to specify a selection specification""")
         Returns:
             Element containing the sampled coordinates
         """
+        if samples is None:
+            samples = []
         if kwargs and samples != []:
             raise Exception('Supply explicit list of samples or kwargs, not both.')
         elif kwargs:
@@ -760,7 +761,7 @@ argument to specify a selection specification""")
             for dim, val in kwargs.items():
                 sample[self.get_dimension_index(dim)] = val
             samples = [tuple(sample)]
-        elif isinstance(samples, tuple) or util.isscalar(samples):
+        elif isinstance(samples, tuple) or core_util.isscalar(samples):
             if self.ndims == 1:
                 xlim = self.range(0)
                 lower, upper = (xlim[0], xlim[1]) if bounds is None else bounds
@@ -784,12 +785,12 @@ argument to specify a selection specification""")
             else:
                 raise NotImplementedError("Regular sampling not implemented "
                                           "for elements with more than two dimensions.")
-            samples = list(util.unique_iterator(self.closest(linsamples)))
+            samples = list(core_util.unique_iterator(self.closest(linsamples)))
 
         # Note: Special handling sampling of gridded 2D data as Curve
         # may be replaced with more general handling
         # see https://github.com/holoviz/holoviews/issues/1173
-        from ...element import Table, Curve
+        from ...element import Curve, Table
         datatype = ['dataframe', 'dictionary', 'dask', 'ibis', 'cuDF']
         if len(samples) == 1:
             sel = {kd.name: s for kd, s in zip(self.kdims, samples[0])}
@@ -810,11 +811,11 @@ argument to specify a selection specification""")
                 reindexed = selection.clone(new_type=Dataset, datatype=datatype).reindex(kdims)
                 selection = tuple(reindexed.columns(kdims+self.vdims).values())
 
-            datatype = list(util.unique_iterator(self.datatype+['dataframe', 'dict']))
+            datatype = list(core_util.unique_iterator([*self.datatype, 'dataframe', 'dict']))
             return self.clone(selection, kdims=kdims, new_type=new_type,
                               datatype=datatype)
 
-        lens = {len(util.wrap_tuple(s)) for s in samples}
+        lens = {len(core_util.wrap_tuple(s)) for s in samples}
         if len(lens) > 1:
             raise IndexError('Sample coordinates must all be of the same length.')
 
@@ -823,12 +824,12 @@ argument to specify a selection specification""")
                 samples = self.closest(samples)
             except NotImplementedError:
                 pass
-        samples = [util.wrap_tuple(s) for s in samples]
+        samples = [core_util.wrap_tuple(s) for s in samples]
         sampled = self.interface.sample(self, samples)
         return self.clone(sampled, new_type=Table, datatype=datatype)
 
 
-    def reduce(self, dimensions=[], function=None, spreadfn=None, **reductions):
+    def reduce(self, dimensions=None, function=None, spreadfn=None, **reductions):
         """Applies reduction along the specified dimension(s).
 
         Allows reducing the values along one or more key dimension
@@ -856,6 +857,8 @@ argument to specify a selection specification""")
         Returns:
             The Dataset after reductions have been applied.
         """
+        if dimensions is None:
+            dimensions = []
         if any(dim in self.vdims for dim in dimensions):
             raise Exception("Reduce cannot be applied to value dimensions")
         function, dims = self._reduce_map(dimensions, function, reductions)
@@ -907,7 +910,7 @@ argument to specify a selection specification""")
         if not self:
             if spreadfn:
                 spread_name = spreadfn.__name__
-                vdims = [d for vd in self.vdims for d in [vd, vd.clone('_'.join([vd.name, spread_name]))]]
+                vdims = [d for vd in self.vdims for d in [vd, vd.clone(f'{vd.name}_{spread_name}')]]
             else:
                 vdims = self.vdims
             if not kdims and len(vdims) == 1:
@@ -925,8 +928,8 @@ argument to specify a selection specification""")
             ndims = len(vdims)
             error = self.clone(error, kdims=kdims, new_type=Dataset)
             combined = self.clone(aggregated, kdims=kdims, new_type=Dataset)
-            for i, d in enumerate(vdims):
-                dim = d.clone('_'.join([d.name, spread_name]))
+            for d in vdims:
+                dim = d.clone(f'{d.name}_{spread_name}')
                 dvals = error.dimension_values(d, flat=False)
                 idx = vdims.index(d)
                 combined = combined.add_dimension(dim, idx+1, dvals, True)
@@ -945,7 +948,7 @@ argument to specify a selection specification""")
                                   new_type=new_type, datatype=datatype)
 
 
-    def groupby(self, dimensions=[], container_type=HoloMap, group_type=None,
+    def groupby(self, dimensions=None, container_type=HoloMap, group_type=None,
                 dynamic=False, **kwargs):
         """Groups object by one or more dimensions
 
@@ -964,6 +967,8 @@ argument to specify a selection specification""")
             Returns object of supplied container_type containing the
             groups. If dynamic=True returns a DynamicMap instead.
         """
+        if dimensions is None:
+            dimensions = []
         if not isinstance(dimensions, list): dimensions = [dimensions]
         if not len(dimensions): dimensions = self.dimensions('key', True)
         if group_type is None: group_type = type(self)
@@ -975,7 +980,7 @@ argument to specify a selection specification""")
             group_dims = [kd for kd in self.kdims if kd not in dimensions]
             kdims = [self.get_dimension(d) for d in kwargs.pop('kdims', group_dims)]
             drop_dim = len(group_dims) != len(kdims)
-            group_kwargs = dict(util.get_param_values(self), kdims=kdims)
+            group_kwargs = dict(core_util.get_param_values(self), kdims=kdims)
             group_kwargs.update(kwargs)
             def load_subset(*args):
                 constraint = dict(zip(dim_names, args))
@@ -1023,11 +1028,11 @@ argument to specify a selection specification""")
         """
         drop = kwargs.pop('drop', False)
         keep_index = kwargs.pop('keep_index', True)
-        transforms = OrderedDict()
+        transforms = {}
         for s, transform in list(args)+list(kwargs.items()):
-            transforms[util.wrap_tuple(s)] = transform
+            transforms[core_util.wrap_tuple(s)] = transform
 
-        new_data = OrderedDict()
+        new_data = {}
         for signature, transform in transforms.items():
             applied = transform.apply(
                 self, compute=False, keep_index=keep_index
@@ -1050,10 +1055,10 @@ argument to specify a selection specification""")
         if drop:
             kdims = [ds.get_dimension(d) for d in new_data if d in ds.kdims]
             vdims = [ds.get_dimension(d) or d for d in new_data if d not in ds.kdims]
-            data = OrderedDict([(dimension_name(d), values) for d, values in new_data.items()])
+            data = dict([(dimension_name(d), values) for d, values in new_data.items()])
             return ds.clone(data, kdims=kdims, vdims=vdims)
         else:
-            new_data = OrderedDict([(dimension_name(d), values) for d, values in new_data.items()])
+            new_data = dict([(dimension_name(d), values) for d, values in new_data.items()])
             data = ds.interface.assign(ds, new_data)
             data, drop = data if isinstance(data, tuple) else (data, [])
             kdims = [kd for kd in self.kdims if kd.name not in drop]
@@ -1093,7 +1098,7 @@ argument to specify a selection specification""")
         values = self.interface.values(self, dim, expanded, flat)
         if dim.nodata is not None:
             # Ensure nodata applies to boolean data in py2
-            values = np.where(values==dim.nodata, np.NaN, values)
+            values = np.where(values==dim.nodata, np.nan, values)
         return values
 
     def get_dimension_type(self, dim):
@@ -1153,7 +1158,7 @@ argument to specify a selection specification""")
             dimensions = self.dimensions()
         else:
             dimensions = [self.get_dimension(d, strict=True) for d in dimensions]
-        return OrderedDict([(d.name, self.dimension_values(d)) for d in dimensions])
+        return dict([(d.name, self.dimension_values(d)) for d in dimensions])
 
 
     @property
@@ -1180,8 +1185,8 @@ argument to specify a selection specification""")
             Cloned object
         """
         if 'datatype' not in overrides:
-            datatypes = [self.interface.datatype] + self.datatype
-            overrides['datatype'] = list(util.unique_iterator(datatypes))
+            datatypes = [self.interface.datatype, *self.datatype]
+            overrides['datatype'] = list(core_util.unique_iterator(datatypes))
 
         if data is None:
             overrides['_validate_vdims'] = False
@@ -1264,3 +1269,6 @@ argument to specify a selection specification""")
             dataset.ndloc[[1, 2, 3], [0, 2, 3]]
         """
         return ndloc(self)
+
+    # This is to work with spatialpandas-dask with dask 2025.1
+    __dask_tokenize__ = __getstate__
