@@ -123,7 +123,7 @@ class VLine(Annotation):
 
     group = param.String(default='VLine', constant=True)
 
-    x = param.ClassSelector(default=0, class_=(Number,) + datetime_types, doc="""
+    x = param.ClassSelector(default=0, class_=(Number, *datetime_types), doc="""
        The x-position of the VLine which make be numeric or a timestamp.""")
 
     __pos_params = ['x']
@@ -158,7 +158,7 @@ class HLine(Annotation):
 
     group = param.String(default='HLine', constant=True)
 
-    y = param.ClassSelector(default=0, class_=(Number,) + datetime_types, doc="""
+    y = param.ClassSelector(default=0, class_=(Number, *datetime_types), doc="""
        The y-position of the HLine which make be numeric or a timestamp.""")
 
     __pos_params = ['y']
@@ -229,10 +229,10 @@ class VSpan(Annotation):
 
     group = param.String(default='VSpan', constant=True)
 
-    x1 = param.ClassSelector(default=0, class_=(Number,) + datetime_types, allow_None=True, doc="""
+    x1 = param.ClassSelector(default=0, class_=(Number, *datetime_types), allow_None=True, doc="""
        The start x-position of the VSpan which must be numeric or a timestamp.""")
 
-    x2 = param.ClassSelector(default=0, class_=(Number,) + datetime_types, allow_None=True, doc="""
+    x2 = param.ClassSelector(default=0, class_=(Number, *datetime_types), allow_None=True, doc="""
        The end x-position of the VSpan which must be numeric or a timestamp.""")
 
     __pos_params = ['x1', 'x2']
@@ -265,10 +265,10 @@ class HSpan(Annotation):
 
     group = param.String(default='HSpan', constant=True)
 
-    y1 = param.ClassSelector(default=0, class_=(Number,) + datetime_types, allow_None=True, doc="""
+    y1 = param.ClassSelector(default=0, class_=(Number, *datetime_types), allow_None=True, doc="""
        The start y-position of the VSpan which must be numeric or a timestamp.""")
 
-    y2 = param.ClassSelector(default=0, class_=(Number,) + datetime_types, allow_None=True, doc="""
+    y2 = param.ClassSelector(default=0, class_=(Number, *datetime_types), allow_None=True, doc="""
        The end y-position of the VSpan which must be numeric or a timestamp.""")
 
     __pos_params = ['y1', 'y2']
@@ -360,20 +360,20 @@ class Arrow(Annotation):
     specified as well as the arrow head style.
     """
 
-    x = param.ClassSelector(default=0, class_=(Number, ) + datetime_types, doc="""
+    x = param.ClassSelector(default=0, class_=(Number, *datetime_types), doc="""
        The x-position of the arrow which make be numeric or a timestamp.""")
 
-    y = param.ClassSelector(default=0, class_=(Number, ) + datetime_types, doc="""
+    y = param.ClassSelector(default=0, class_=(Number, *datetime_types), doc="""
        The y-position of the arrow which make be numeric or a timestamp.""")
 
     text = param.String(default='', doc="Text associated with the arrow.")
 
-    direction = param.ObjectSelector(default='<',
+    direction = param.Selector(default='<',
                                      objects=['<', '^', '>', 'v'], doc="""
         The cardinal direction in which the arrow is pointing. Accepted
         arrow directions are '<', '^', '>' and 'v'.""")
 
-    arrowstyle = param.ObjectSelector(default='->',
+    arrowstyle = param.Selector(default='->',
                                       objects=['-', '->', '-[', '-|>', '<->', '<|-|>'],
                                       doc="""
         The arrowstyle used to draw the arrow. Accepted arrow styles are
@@ -430,10 +430,10 @@ class Text(Annotation):
     Draw a text annotation at the specified position with custom
     fontsize, alignment and rotation.
     """
-    x = param.ClassSelector(default=0, class_=(Number, str) + datetime_types, doc="""
+    x = param.ClassSelector(default=0, class_=(Number, str, *datetime_types), doc="""
        The x-position of the arrow which make be numeric or a timestamp.""")
 
-    y = param.ClassSelector(default=0, class_=(Number, str) + datetime_types, doc="""
+    y = param.ClassSelector(default=0, class_=(Number, str, *datetime_types), doc="""
        The y-position of the arrow which make be numeric or a timestamp.""")
 
     text = param.String(default='', doc="The text to be displayed.")
@@ -442,12 +442,12 @@ class Text(Annotation):
 
     rotation = param.Number(default=0, doc="Text rotation angle in degrees.")
 
-    halign = param.ObjectSelector(default='center',
+    halign = param.Selector(default='center',
                                   objects=['left', 'right', 'center'], doc="""
        The horizontal alignment position of the displayed text. Allowed values
        are 'left', 'right' and 'center'.""")
 
-    valign = param.ObjectSelector(default='center',
+    valign = param.Selector(default='center',
                                   objects=['top', 'bottom', 'center'], doc="""
        The vertical alignment position of the displayed text. Allowed values
        are 'center', 'top' and 'bottom'.""")
