@@ -1,10 +1,13 @@
 import numpy as np
 import param
 
-from ..core import util
-from ..core import Dimension, Dataset, Element2D, NdOverlay, Overlay
+from ..core import Dataset, Dimension, Element2D, NdOverlay, Overlay, util
 from ..core.dimension import process_dimensions
-from .geom import Rectangles, Points, VectorField # noqa: backward compatible import
+from .geom import (  # noqa: F401 backward compatible import
+    Points,
+    Rectangles,
+    VectorField,
+)
 from .selection import Selection1DExpr
 
 
@@ -83,7 +86,7 @@ class ErrorBars(Selection1DExpr, Chart):
     location along the x-axis and the first value dimension
     corresponds to the location along the y-axis and one or two
     extra value dimensions corresponding to the symmetric or
-    asymetric errors either along x-axis or y-axis. If two value
+    asymmetric errors either along x-axis or y-axis. If two value
     dimensions are given, then the last value dimension will be
     taken as symmetric errors. If three value dimensions are given
     then the last two value dimensions will be taken as negative and
@@ -105,7 +108,7 @@ class ErrorBars(Selection1DExpr, Chart):
     def range(self, dim, data_range=True, dimension_range=True):
         """Return the lower and upper bounds of values along dimension.
 
-        Range of the y-dimension includes the symmetric or assymetric
+        Range of the y-dimension includes the symmetric or asymmetric
         error.
 
         Args:
@@ -142,7 +145,7 @@ class Spread(ErrorBars):
     confidence band in a 1D coordinate system. The key dimension(s)
     corresponds to the location along the x-axis and the value
     dimensions define the location along the y-axis as well as the
-    symmetric or assymetric spread.
+    symmetric or asymmetric spread.
     """
 
     group = param.String(default='Spread', constant=True)
@@ -215,7 +218,7 @@ class Spikes(Selection1DExpr, Chart):
 
     kdims = param.List(default=[Dimension('x')], bounds=(1, 1))
 
-    vdims = param.List(default=[])
+    vdims = param.List(default=[], bounds=(0, None))
 
     _auto_indexable_1d = False
 
@@ -248,11 +251,16 @@ class Area(Curve):
             areas = NdOverlay({i: el for i, el in enumerate(areas)})
         df = areas.dframe(multi_index=True)
         levels = list(range(areas.ndims))
-        vdim = areas.last.vdims[0]
-        vdims = [vdim, baseline_name]
+        vdims = [[el.vdims[0], baseline_name] for el in areas]
         baseline = None
         stacked = areas.clone(shared_data=False)
-        for key, sdf in df.groupby(level=levels, sort=False):
+        if len(levels) == 1:
+            # Pandas 2.1 gives the following FutureWarning:
+            #   Creating a Groupby object with a length-1 list-like level parameter
+            #   will yield indexes as tuples in a future version.
+            levels = levels[0]
+        for (key, sdf), element_vdims in zip(df.groupby(level=levels, sort=False), vdims):
+            vdim = element_vdims[0]
             sdf = sdf.droplevel(levels).reindex(index=df.index.unique(-1), fill_value=0)
             if baseline is None:
                 sdf[baseline_name] = 0
@@ -260,5 +268,5 @@ class Area(Curve):
                 sdf[vdim.name] = sdf[vdim.name] + baseline
                 sdf[baseline_name] = baseline
             baseline = sdf[vdim.name]
-            stacked[key] = areas[key].clone(sdf, vdims=vdims)
+            stacked[key] = areas[key].clone(sdf, vdims=element_vdims)
         return Overlay(stacked.values()) if is_overlay else stacked
