@@ -10,10 +10,13 @@ class TabularSelectionDisplay(SelectionDisplay):
     def _build_selection(self, el, exprs, **kwargs):
         opts = {}
         if exprs[1]:
-            opts['selected'] = np.where(exprs[1].apply(el.dataset, expanded=True, flat=True))[0]
+            mask = exprs[1].apply(el.dataset, expanded=True, flat=True)
+            opts['selected'] = list(np.where(mask)[0])
         return el.opts(clone=True, backend='bokeh', **opts)
 
-    def build_selection(self, selection_streams, hvobj, operations, region_stream=None):
+    def build_selection(self, selection_streams, hvobj, operations, region_stream=None, cache=None):
+        if cache is None:
+            cache = {}
         sel_streams = [selection_streams.exprs_stream]
         hvobj = hvobj.apply(self._build_selection, streams=sel_streams, per_element=True)
         for op in operations:
@@ -51,7 +54,9 @@ class BokehOverlaySelectionDisplay(OverlaySelectionDisplay):
                 merged_opts[opt] = opts[opt]
 
         filtered = {k: v for k, v in merged_opts.items() if k in allowed}
-        return element.opts(backend='bokeh', clone=True, tools=['box_select'],
+        plot_opts = Store.lookup_options('bokeh', element, 'plot').kwargs
+        tools = [*plot_opts.get('tools', []), 'box_select']
+        return element.opts(backend='bokeh', clone=True, tools=tools,
                             **filtered)
 
     def _style_region_element(self, region_element, unselected_color):
