@@ -112,19 +112,19 @@ class Renderer(Exporter):
     dpi = param.Integer(default=None, doc="""
         The render resolution in dpi (dots per inch)""")
 
-    fig = param.ObjectSelector(default='auto', objects=['auto'], doc="""
+    fig = param.Selector(default='auto', objects=['auto'], doc="""
         Output render format for static figures. If None, no figure
         rendering will occur. """)
 
     fps = param.Number(default=20, doc="""
         Rendered fps (frames per second) for animated formats.""")
 
-    holomap = param.ObjectSelector(default='auto',
+    holomap = param.Selector(default='auto',
                                    objects=['scrubber','widgets', None, 'auto'], doc="""
         Output render multi-frame (typically animated) format. If
         None, no multi-frame rendering will occur.""")
 
-    mode = param.ObjectSelector(default='default',
+    mode = param.Selector(default='default',
                                 objects=['default', 'server'], doc="""
         Whether to render the object in regular or server mode. In server
         mode a bokeh Document will be returned which can be served as a
@@ -133,13 +133,13 @@ class Renderer(Exporter):
     size = param.Integer(default=100, doc="""
         The rendered size as a percentage size""")
 
-    widget_location = param.ObjectSelector(default=None, allow_None=True, objects=[
+    widget_location = param.Selector(default=None, allow_None=True, objects=[
         'left', 'bottom', 'right', 'top', 'top_left', 'top_right',
         'bottom_left', 'bottom_right', 'left_top', 'left_bottom',
         'right_top', 'right_bottom'], doc="""
         The position of the widgets relative to the plot.""")
 
-    widget_mode = param.ObjectSelector(default='embed', objects=['embed', 'live'], doc="""
+    widget_mode = param.Selector(default='embed', objects=['embed', 'live'], doc="""
         The widget mode determining whether frames are embedded or generated
         'live' when interacting with the widget.""")
 
@@ -352,7 +352,7 @@ class Renderer(Exporter):
             figdata = figdata.encode("utf-8")
         elif fmt == 'pdf' and 'height' not in css:
             _, h = self.get_size(plot)
-            css['height'] = '%dpx' % (h*self.dpi*1.15)
+            css['height'] = f"{int(h*self.dpi*1.15)}px"
 
         if isinstance(css, dict):
             css = '; '.join(f"{k}: {v}" for k, v in css.items())
@@ -473,7 +473,7 @@ class Renderer(Exporter):
         data to a json file in the supplied json_path (defaults to
         current path).
         """
-        if fmt not in self_or_cls.widgets+['auto', None]:
+        if fmt not in [*self_or_cls.widgets, "auto", None]:
             raise ValueError("Renderer.export_widget may only export "
                              "registered widget types.")
         self_or_cls.get_widget(obj, fmt).save(filename)
