@@ -456,12 +456,12 @@ class TestTreePathUtils(unittest.TestCase):
     def test_make_path_unique_clash_without_label(self):
         path = ('Element',)
         new_path = make_path_unique(path, {path: 1}, True)
-        self.assertEqual(new_path, path+('I',))
+        self.assertEqual(new_path, (*path, 'I'))
 
     def test_make_path_unique_clash_with_label(self):
         path = ('Element', 'A')
         new_path = make_path_unique(path, {path: 1}, True)
-        self.assertEqual(new_path, path+('I',))
+        self.assertEqual(new_path, (*path, 'I'))
 
     def test_make_path_unique_no_clash_old(self):
         path = ('Element', 'A')
@@ -471,7 +471,7 @@ class TestTreePathUtils(unittest.TestCase):
     def test_make_path_unique_clash_without_label_old(self):
         path = ('Element',)
         new_path = make_path_unique(path, {path: 1}, False)
-        self.assertEqual(new_path, path+('I',))
+        self.assertEqual(new_path, (*path, 'I'))
 
     def test_make_path_unique_clash_with_label_old(self):
         path = ('Element', 'A')
@@ -639,12 +639,12 @@ class TestNumericUtilities(ComparisonTestCase):
 
     def test_isfinite_pandas_period_index_nat(self):
         daily = pd.date_range('2017-1-1', '2017-1-3', freq='D').to_period('D')
-        daily = pd.PeriodIndex(list(daily)+[pd.NaT])
+        daily = pd.PeriodIndex([*daily, pd.NaT])
         self.assertEqual(isfinite(daily), np.array([True, True, True, False]))
 
     def test_isfinite_pandas_period_series_nat(self):
         daily = pd.date_range('2017-1-1', '2017-1-3', freq='D').to_period('D')
-        daily = pd.Series(list(daily)+[pd.NaT])
+        daily = pd.Series([*daily, pd.NaT])
         self.assertEqual(isfinite(daily), np.array([True, True, True, False]))
 
     def test_isfinite_pandas_timestamp_index(self):
@@ -657,12 +657,12 @@ class TestNumericUtilities(ComparisonTestCase):
 
     def test_isfinite_pandas_timestamp_index_nat(self):
         daily = pd.date_range('2017-1-1', '2017-1-3', freq='D')
-        daily = pd.DatetimeIndex(list(daily)+[pd.NaT])
+        daily = pd.DatetimeIndex([*daily, pd.NaT])
         self.assertEqual(isfinite(daily), np.array([True, True, True, False]))
 
     def test_isfinite_pandas_timestamp_series_nat(self):
         daily = pd.date_range('2017-1-1', '2017-1-3', freq='D')
-        daily = pd.Series(list(daily)+[pd.NaT])
+        daily = pd.Series([*daily, pd.NaT])
         self.assertEqual(isfinite(daily), np.array([True, True, True, False]))
 
     def test_isfinite_datetime64_array(self):
@@ -671,7 +671,7 @@ class TestNumericUtilities(ComparisonTestCase):
 
     def test_isfinite_datetime64_array_with_nat(self):
         dts = [np.datetime64(datetime.datetime(2017, 1, i)) for i in range(1, 4)]
-        dt64 = np.array(dts+[np.datetime64('NaT')])
+        dt64 = np.array([*dts, np.datetime64('NaT')])
         self.assertEqual(isfinite(dt64), np.array([True, True, True, False]))
 
 
