@@ -351,6 +351,27 @@ class TestBarPlot(TestBokehPlot):
         plot = bokeh_renderer.get_plot(bars)
         assert plot.handles["glyph"].width == 1
 
+    def test_bars_categorical_order(self):
+        cells_dtype = pd.CategoricalDtype(
+            pd.array(["~1M", "~10M", "~100M"], dtype="string"),
+            ordered=True,
+        )
+        df = pd.DataFrame(dict(
+            cells=cells_dtype.categories.astype(cells_dtype),
+            time=pd.array([2.99, 18.5, 835.2]),
+            function=pd.array(["read", "read", "read"]),
+        ))
+
+        bars = Bars(df, ["function", "cells"], ["time"])
+        plot = bokeh_renderer.get_plot(bars)
+        x_factors = plot.handles["x_range"].factors
+
+        np.testing.assert_equal(x_factors, [
+            ("read", "~1M"),
+            ("read", "~10M"),
+            ("read", "~100M"),
+        ])
+
     def test_bars_group(self):
         samples = 100
 
